#!/bin/sh
#
# Drizzle PHP Extension
#
# Copyright (C) 2008 Eric Day (eday@oddments.org)
# All rights reserved.
#
# Use and distribution licensed under the PHP license.  See
# the LICENSE file in this directory for full text.
#

if [ "$1" = "" ]
then
  header=/usr/local/include/libdrizzle/constants.h
else
  header=$1
fi

if [ ! -e $header ]
then
  echo "$header does not exist"
  exit 1;
fi

if [ -e php_drizzle.c.new ]
then
  echo "php_drizzle.c.new already exists"
  exit 1;
fi

awk 'BEGIN { p= 1; } \
     /CONST_GEN_START/ { p= 0; print $0; } \
     { if (p == 1) { print $0; } }' php_drizzle.c >> php_drizzle.c.new

grep ' DRIZZLE' $header | \
  sed 's/.* \(DRIZZLE[A-Z0-9_]*\).*/\1/' | \
  grep -v __DRIZZLE | sort | uniq | \
  sed 's/\(.*\)/  REGISTER_LONG_CONSTANT("\1",\
                         \1,\
                         CONST_CS | CONST_PERSISTENT);/' | \
  sed 's/LONG\(.*DRIZZLE_DEFAULT_TCP_HOST\)/STRING\1/' | \
  sed 's/LONG\(.*DRIZZLE_DEFAULT_UDS\)/STRING\1/' | \
  sed 's/LONG\(.*DRIZZLE_DEFAULT_USER\)/STRING\1/' >> php_drizzle.c.new

awk 'BEGIN { p= 0; } \
     /CONST_GEN_STOP/ { p= 1; } \
     { if (p == 1) { print $0; } }' php_drizzle.c >> php_drizzle.c.new

echo "New source file can be found in: php_drizzle.c.new"

exit 0
